@@ -71,9 +71,9 @@ test_options = {
                   PYOC, 'base_2.7', 2.7),
 }
 
-for vers in (1.4, 1.5, 2.1, 2.2, 2.3, 2.4, 2.5, '2.5dropbox',
-             2.6, 2.7, 3.0, 3.1,
-             3.2, 3.3, 3.4, 3.5, '3.2pypy', '2.7pypy',
+for vers in (1.0, 1.1, 1.2, 1.3, 1.4, 1.5, 1.6,
+             2.1, 2.2, 2.3, 2.4, 2.5, '2.5dropbox', 2.6, 2.7,
+             3.0, 3.1, 3.2, 3.3, 3.4, 3.5, '3.2pypy', '2.7pypy',
              3.6, 3.7):
     bytecode = "bytecode_%s" % vers
     key = "bytecode-%s" % vers
