@@ -19,9 +19,12 @@ import sys
 from xdis import IS_PYPY
 from xdis.magics import canonic_python_version
 
+from xdis.opcodes import opcode_10 as opcode_10
+from xdis.opcodes import opcode_11 as opcode_11
 from xdis.opcodes import opcode_13 as opcode_13
 from xdis.opcodes import opcode_14 as opcode_14
 from xdis.opcodes import opcode_15 as opcode_15
+from xdis.opcodes import opcode_16 as opcode_16
 from xdis.opcodes import opcode_20 as opcode_20
 from xdis.opcodes import opcode_21 as opcode_21
 from xdis.opcodes import opcode_22 as opcode_22
@@ -48,13 +51,20 @@ from xdis.opcodes import opcode_36pypy as opcode_36pypy
 
 # FIXME
 op_imports = {
+    1.0     : opcode_10,
+    '1.0'   : opcode_10,
+    1.1     : opcode_11,
+    '1.1'   : opcode_11,
+    1.2     : opcode_11,
+    '1.2'   : opcode_11,
     1.3     : opcode_13,
     '1.3'   : opcode_13,
     1.4     : opcode_14,
     '1.4'   : opcode_14,
     1.5     : opcode_15,
     '1.5'   : opcode_15,
-    1.5     : opcode_15,
+    1.6     : opcode_16,
+    '1.6'   : opcode_16,
     '2.0'   : opcode_20,
     2.0     : opcode_20,
     '2.1'   : opcode_21,
